## Create

Glyphs shows the Start Window when opened without documents:
The right side contains information about the Glyphs version and links to the Glyphs website.
Uncheck “Show window on startup” to hide the window on future launches.

The left side shows a list of recently opened documents.
Double-click a document to open it.
Open the Start Window anytime from the menu bar: “Window” → “Start Window”.

Tip:

Control-click or right-click a document and choose “Show in Finder” from the context menu to reveal the file in Finder.

Click the plus  button to create a new Glyphs document.
The Start Window then lists a set of scripts.
These scripts are also shown when there are no recent files.

Click a script and include it in the new document by toggling “No” to “Yes” in the top-right of the window.
Included scripts appear with a colored icon in the list.
Customize the included glyphs by toggling the respective checkboxes on the right side.
Search for scripts by name using the search field in the top-right corner of the window.

Create a document containing empty glyphs for all selected scripts using the “Create Document” button in the lower right:

Save the document with “File” → “Save” (Cmd-S).
Give the file a name and pick a folder in which to save it.
Glyphs offers three file format options.

A Glyphs document can be changed to a different file format at any time with “File” → “Save As…” (Cmd-Shift-S).

See Source Formats for details, or pick the default “Glyphs File” for a start.

Create a new document at any time with “File” → “New from Glyph Sets…”
The list remembers the previous selection of scripts and glyph sets.
Quickly create a new document with the basic ASCII glyphs by choosing “File” → “New” (Cmd-N).

See the Getting Started tutorials on the Glyphs website for an introduction to working with Glyphs.